@@ -140,8 +140,7 @@ class Client_v1(AbstractContextManager):
         logger.debug(f'HTTP Response: {response}')
         response.raise_for_status()
         validate.RESTful_XML(response.content)
-        # TODO: Do we want to 'parse' this, so it is similar to what is returned from get()?
-        return response.content
+        return parse.RESTful_XML(response.content)
 
     def delete(self, url):
         """
@@ -162,7 +161,6 @@ class Client_v1(AbstractContextManager):
         response = self.http.delete(self.base_url + url, timeout=self.timeout)
         logger.debug(f'HTTP Response: {response}')
         response.raise_for_status()
-        # TODO: Do we want to 'parse' this, so it is similar to what is returned from get()?
         return response.content
 
     def create_object(self, object, data):
@@ -202,6 +200,21 @@ class Client_v1(AbstractContextManager):
         """
         return self.post("/" + object, data)
 
+    def delete_object_by_id(self, object, id):
+        """
+        This function deletes an object record by it's id
+
+        Arguments:
+          object -- 'device', 'vlan', etc...
+          id  -- Object ID
+
+        Usage:
+          response = netdot.Client.delete_object_by_id("device", "id")
+
+        Returns:
+        """
+        return self.delete("/" + object + "/" + id)
+
 
 class Client(Client_v1):
     """NetDot Client (v2) -- provides access to NetDot data directly as dicts.
