@@ -36,6 +36,10 @@ class NetdotAPIDataclass():
             cls._logged_unused_fields = set()
             cls._initialized = True
 
+    def replace(self, **kwargs):
+        import dataclasses
+        return dataclasses.replace(self, **kwargs)
+
     @classmethod
     def _attach_methods(cls, methods):
         for method in methods:
