@@ -187,17 +187,18 @@ class Repository:
 
     @trace
     def update_site(self, site_id, new_data: 'netdot.dataclasses.Site'):
-        self.connection.post(
+        return self.connection.post(
             f'/{new_data.NETDOT_TABLE_NAME}/{site_id}', new_data.to_DTO())
 
     @trace
     def create_site(self, new_site: 'netdot.dataclasses.Site'):
-        self.connection.create_object(
+        return self.connection.create_object(
             new_site.NETDOT_TABLE_NAME, new_site.to_DTO())
 
     @trace
     def delete_site(self, site_id):
-        raise NotImplementedError()
+        return self.connection.delete_object_by_id(
+            netdot.dataclasses.Site.NETDOT_TABLE_NAME, site_id)
 
     @classmethod
     def _getters_for_all_dataclasses(cls, dataclasses) -> List:
@@ -273,7 +274,6 @@ def _generate_xlink_by_id_getter(dataclass, xlink_class):
         ]
     return xlink_by_id_getter
 
-
 def _generate_xlink_getter(dataclass, xlink_class):
 
     def xlink_getter(repo: 'Repository', entity: xlink_class) -> List[dataclass]:
