@@ -53,4 +53,4 @@ def test_create_object_site(client: Client):
     })
 
     # Assert
-    assert_that(site).is_not_none()
+    assert_that(site['name']).is_equal_to('Test site 123')
